@@ -46,11 +46,12 @@ class Rate implements Iterator<Row<Sample>>, Iterable<Row<Sample>> {
 
     private final Iterator<Row<Sample>> m_input;
     private final Set<String> m_metrics;
-    private final Map<String, Sample> m_prevSamples = Maps.newHashMap();
+    private final Map<String, Sample> m_prevSamples;
 
     Rate(Iterator<Row<Sample>> input, Set<String> metrics) {
         m_input = checkNotNull(input, "input argument");
         m_metrics = checkNotNull(metrics, "metrics argument");
+        m_prevSamples = Maps.newHashMapWithExpectedSize(m_metrics.size());
     }
 
     @Override
@@ -90,7 +91,11 @@ class Rate implements Iterator<Row<Sample>>, Iterable<Row<Sample>> {
 
         if (previous != null) {
             long elapsed = sample.getTimestamp().asSeconds() - previous.getTimestamp().asSeconds();
-            value = sample.getValue().delta(previous.getValue()).divideBy(elapsed);
+            try {
+                value = new Gauge(sample.getValue().delta(previous.getValue()).doubleValue() / elapsed);
+            } catch (ArithmeticException e) {
+                value = NAN;
+            }
         }
 
         return new Sample(sample.getTimestamp(), sample.getResource(), sample.getName(), GAUGE, value, sample.getAttributes());
