@@ -28,6 +28,7 @@ import org.slf4j.LoggerFactory;
 
 import com.codahale.metrics.Meter;
 import com.codahale.metrics.MetricRegistry;
+import com.google.common.annotations.VisibleForTesting;
 import com.google.common.base.Joiner;
 import com.google.common.base.Optional;
 import com.google.common.cache.Cache;
@@ -63,6 +64,11 @@ public class GuavaResourceMetadataCache implements ResourceMetadataCache {
         return (r != null) ? Optional.of(r) : Optional.<ResourceMetadata>absent();
     }
 
+    @Override
+    public void delete(Context context, Resource resourceId) {
+        m_cache.invalidate(key(context, resourceId));
+    }
+
     private String key(Context context, Resource resource) {
         return m_keyJoiner.join(context.getId(), resource.getId());
     }
@@ -83,4 +89,9 @@ public class GuavaResourceMetadataCache implements ResourceMetadataCache {
 
     }
 
+    @VisibleForTesting
+    protected Cache<String, ResourceMetadata> getCache() {
+        return m_cache;
+    }
+
 }
