@@ -33,11 +33,12 @@ import org.opennms.newts.api.Sample;
 import org.opennms.newts.api.Results.Row;
 import org.opennms.newts.api.Timestamp;
 
+import com.datastax.driver.core.ConsistencyLevel;
 import com.google.common.base.Optional;
 import com.google.common.collect.Lists;
 
 
-public class InsertSelectSamplesITCase extends AbstractCassandraTestCase {
+public class InsertSelectSamplesITCase extends NewtsSampleRepositoryTestCase {
 
     @Test
     public void test() {
@@ -55,7 +56,8 @@ public class InsertSelectSamplesITCase extends AbstractCassandraTestCase {
         }
 
         // Override the shard period to ensure we test query concurrency
-        m_contextConfigurations.addContextConfig(Context.DEFAULT_CONTEXT, Duration.seconds(1));
+        m_contextConfigurations.addContextConfig(Context.DEFAULT_CONTEXT,
+                Duration.seconds(1), ConsistencyLevel.ALL, ConsistencyLevel.ALL);
 
         getRepository().insert(samples);
 
